==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceConversionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceConversionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionBuilder>{
  public CustomResourceConversionBuilder() {
    this(false);
  }
  public CustomResourceConversionBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceConversion(), validationEnabled);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceConversion(), validationEnabled);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance) {
    this(fluent, instance, false);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withStrategy(instance.getStrategy()); 
    fluent.withWebhook(instance.getWebhook()); 
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance) {
    this(instance,false);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withStrategy(instance.getStrategy()); 
    this.withWebhook(instance.getWebhook()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion build() {
    CustomResourceConversion buildable = new CustomResourceConversion(fluent.getStrategy(),fluent.getWebhook());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceConversionBuilder that = (CustomResourceConversionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceConversionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceConversionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionBuilder>{
  public CustomResourceConversionBuilder() {
    this(false);
  }
  public CustomResourceConversionBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceConversion(), validationEnabled);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceConversion(), validationEnabled);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance) {
    this(fluent, instance, false);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withStrategy(instance.getStrategy()); 
    fluent.withWebhook(instance.getWebhook()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance) {
    this(instance,false);
  }
  public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withStrategy(instance.getStrategy()); 
    this.withWebhook(instance.getWebhook()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion build() {
    CustomResourceConversion buildable = new CustomResourceConversion(fluent.getStrategy(),fluent.getWebhook());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceConversionBuilder that = (CustomResourceConversionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
